from PySide6.QtCore import Qt, QMimeData, QPoint
from PySide6.QtGui import QDrag
from QtSimple6.QsBase import QsBaseWidget


class QsDrag(object):
    def __init__(self, widget: QsBaseWidget):
        self.widget = widget
        self.widget.bind("mousePressEvent", self.press)
        self.widget.bind("mouseMoveEvent", self.move)
        self.iniDragCor = [0, 0]

    def press(self, event):
        self.iniDragCor[0] = event.x()
        self.iniDragCor[1] = event.y()

    def move(self, event):
        x = event.x() - self.iniDragCor[0]
        y = event.y() - self.iniDragCor[1]

        cor = QPoint(x, y)
        self.widget.move(self.widget.mapToParent(QPoint(x, y)))  # 需要maptoparent一下才可以的,否则只是相对位置。



from QtSimple6.QsBase import QsBaseFrame, QWidget
from QtSimple6.QsDrag import QsDrag
from sys import exit


class QsTitleBar(QsBaseFrame):
    def __init__(self, parent: QWidget, window: QWidget):
        super(QsTitleBar, self).__init__(parent=parent)
        self._window = window

    def showMininizedWindow(self):
        self._window.showMinimized()

    def showMaximizedWindow(self):
        self._window.showMaximized()

    def showRestoreWindow(self):
        if self._window.isMaximized():
            self._window.showNormal()
        else:
            self._window.showMaximized()

    def closeWindow(self):
        self._window.close()

    def mouseDoubleClickEvent(self, event):
        self.showRestoreWindow()
        return QWidget().mouseDoubleClickEvent(event)

    def mousePressEvent(self, event):
        self.isPressed = True
        self.startPos = event.globalPosition().toPoint()
        return QWidget().mousePressEvent(event)

    def mouseReleaseEvent(self, event):
        self.isPressed = False
        return QWidget().mouseReleaseEvent(event)

    def mouseMoveEvent(self, event):
        if self.isPressed:
            if self._window.isMaximized:
                self._window.showNormal()

            movePos = event.globalPosition().toPoint() - self.startPos
            self.startPos = event.globalPosition().toPoint()
            self._window.move(self._window.pos() + movePos)

        return QWidget().mouseMoveEvent(event)



from PySide6.QtWidgets import QWidget, QFrame, QPushButton, QToolButton
from PySide6.QtGui import QMouseEvent, QKeyEvent, Qt


def emptyFunc(event=None):
    pass


class QsBaseWidget(QWidget):
    def __init__(self, parent: QWidget = None):
        super(QsBaseWidget, self).__init__(parent=parent)
        self._mousePressEvent = emptyFunc
        self._mouseReleaseEvent = emptyFunc
        self._mouseDoubleClickEvent = emptyFunc
        self._mouseMoveEvent = emptyFunc
        self._keyPressEvent = emptyFunc

    def bind(self, eventName, eventFunc):
        """
        mousePressEvent
        mouseReleaseEvent
        mouseDoubleClickEvent
        mouseMoveEvent
        keyPressEvent
        :param eventName: 事件名称
        :param eventFunc: 事件函数
        :return: 无
        """
        if eventName == 'mousePressEvent':
            self._mousePressEvent = eventFunc
        elif eventName == 'mouseReleaseEvent':
            self._mouseReleaseEvent = eventFunc
        elif eventName == 'mouseDoubleClickEvent':
            self._mouseDoubleClickEvent = eventFunc
        elif eventName == 'mouseMoveEvent':
            self._mouseMoveEvent = eventFunc
        elif eventName == 'keyPressEvent':
            self._keyPressEvent = eventFunc

    def mousePressEvent(self, event: QMouseEvent) -> None:
        self._mousePressEvent(event)

    def mouseReleaseEvent(self, event: QMouseEvent) -> None:
        self._mouseReleaseEvent(event)

    def mouseDoubleClickEvent(self, event: QMouseEvent) -> None:
        self._mouseDoubleClickEvent(event)

    def mouseMoveEvent(self, event: QMouseEvent) -> None:
        self._mouseMoveEvent(event)

    def keyPressEvent(self, event: QKeyEvent) -> None:
        self._keyPressEvent(event)


class QsBaseFrame(QFrame):
    def __init__(self, parent: QWidget = None):
        super(QsBaseFrame, self).__init__(parent=parent)
        self._mousePressEvent = emptyFunc
        self._mouseReleaseEvent = emptyFunc
        self._mouseDoubleClickEvent = emptyFunc
        self._mouseMoveEvent = emptyFunc
        self._keyPressEvent = emptyFunc

    def bind(self, eventName, eventFunc):
        """
        mousePressEvent
        mouseReleaseEvent
        mouseDoubleClickEvent
        mouseMoveEvent
        keyPressEvent
        :param eventName: 事件名称
        :param eventFunc: 事件函数
        :return: 无
        """
        if eventName == 'mousePressEvent':
            self._mousePressEvent = eventFunc
        elif eventName == 'mouseReleaseEvent':
            self._mouseReleaseEvent = eventFunc
        elif eventName == 'mouseDoubleClickEvent':
            self._mouseDoubleClickEvent = eventFunc
        elif eventName == 'mouseMoveEvent':
            self._mouseMoveEvent = eventFunc
        elif eventName == 'keyPressEvent':
            self._keyPressEvent = eventFunc

    def mousePressEvent(self, event: QMouseEvent) -> None:
        self._mousePressEvent(event)

    def mouseReleaseEvent(self, event: QMouseEvent) -> None:
        self._mouseReleaseEvent(event)

    def mouseDoubleClickEvent(self, event: QMouseEvent) -> None:
        self._mouseDoubleClickEvent(event)

    def mouseMoveEvent(self, event: QMouseEvent) -> None:
        self._mouseMoveEvent(event)

    def keyPressEvent(self, event: QKeyEvent) -> None:
        self._keyPressEvent(event)


class QsBasePushButton(QPushButton):
    def __init__(self, parent: QWidget = None, text: str = ""):
        super(QsBasePushButton, self).__init__(parent=parent, text=text)
        self._mousePressEvent = emptyFunc
        self._mouseReleaseEvent = emptyFunc
        self._mouseDoubleClickEvent = emptyFunc
        self._mouseMoveEvent = emptyFunc
        self._keyPressEvent = emptyFunc

    def bind(self, eventName, eventFunc):
        """
        mousePressEvent
        mouseReleaseEvent
        mouseDoubleClickEvent
        mouseMoveEvent
        keyPressEvent
        :param eventName: 事件名称
        :param eventFunc: 事件函数
        :return: 无
        """
        if eventName == 'mousePressEvent':
            self._mousePressEvent = eventFunc
        elif eventName == 'mouseReleaseEvent':
            self._mouseReleaseEvent = eventFunc
        elif eventName == 'mouseDoubleClickEvent':
            self._mouseDoubleClickEvent = eventFunc
        elif eventName == 'mouseMoveEvent':
            self._mouseMoveEvent = eventFunc
        elif eventName == 'keyPressEvent':
            self._keyPressEvent = eventFunc

    def mousePressEvent(self, event: QMouseEvent) -> None:
        self._mousePressEvent(event)

    def mouseReleaseEvent(self, event: QMouseEvent) -> None:
        self._mouseReleaseEvent(event)

    def mouseDoubleClickEvent(self, event: QMouseEvent) -> None:
        self._mouseDoubleClickEvent(event)

    def mouseMoveEvent(self, event: QMouseEvent) -> None:
        self._mouseMoveEvent(event)

    def keyPressEvent(self, event: QKeyEvent) -> None:
        self._keyPressEvent(event)


class QsBaseToolButton(QToolButton):
    def __init__(self, parent: QWidget = None):
        super(QsBaseToolButton, self).__init__(parent=parent)
        self._mousePressEvent = emptyFunc
        self._mouseReleaseEvent = emptyFunc
        self._mouseDoubleClickEvent = emptyFunc
        self._mouseMoveEvent = emptyFunc
        self._keyPressEvent = emptyFunc

    def bind(self, eventName, eventFunc):
        """
        mousePressEvent
        mouseReleaseEvent
        mouseDoubleClickEvent
        mouseMoveEvent
        keyPressEvent
        :param eventName: 事件名称
        :param eventFunc: 事件函数
        :return: 无
        """
        if eventName == 'mousePressEvent':
            self._mousePressEvent = eventFunc
        elif eventName == 'mouseReleaseEvent':
            self._mouseReleaseEvent = eventFunc
        elif eventName == 'mouseDoubleClickEvent':
            self._mouseDoubleClickEvent = eventFunc
        elif eventName == 'mouseMoveEvent':
            self._mouseMoveEvent = eventFunc
        elif eventName == 'keyPressEvent':
            self._keyPressEvent = eventFunc

    def mousePressEvent(self, event: QMouseEvent) -> None:
        self._mousePressEvent(event)

    def mouseReleaseEvent(self, event: QMouseEvent) -> None:
        self._mouseReleaseEvent(event)

    def mouseDoubleClickEvent(self, event: QMouseEvent) -> None:
        self._mouseDoubleClickEvent(event)

    def mouseMoveEvent(self, event: QMouseEvent) -> None:
        self._mouseMoveEvent(event)

    def keyPressEvent(self, event: QKeyEvent) -> None:
        self._keyPressEvent(event)



import setuptools

setuptools.setup(
    name="QtSimple6",
    version="1.0.0",
    author="XiangQinxi",
    author_email="XiangQinxi@outlook.com",
    description="",
    long_description=open("README.md", "r", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    url="https://xiangqinxidevelopment.jetbrains.space/p/tkinterdev",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
